#
#  Copyright 1996-2009 Jim Pirzyk / pirzyk.org
#  All rights reserved.
#
#  Security::util::SHA1 - SHA1 digest generation module.
#
package Security::util::SHA1;

use Digest::SHA1;
use Exporter;
use strict;
use warnings;

our @ISA = qw(Exporter);
our @EXPORT_OK = qw( &init() &check() );

sub init {
	$main::format = "SHA1\\((.*)\\) = (.*)";
}

sub check {
	my ($file) = @_;
	my ($sha) = new Digest::SHA1;
	local *sha_fd;

	open (sha_fd, $file) || return "SHA1($file) = -1\n";
	$sha->reset();
	$sha->addfile(*sha_fd{IO});
	my ($hex) = $sha->hexdigest();
	close sha_fd;
	return "SHA1($file) = $hex\n";
}

1;

__END__

=head1 NAME

Security::util::SHA1 - module for generating SHA1 digests

=head1 SYNOPSIS

Security::util::SHA1::check($file)

=head1 DESCRIPTION

A wrapper routine around C<Digest::SHA1> to return the checksum for a
given file.

=head1 API

The API calls provided by this module

=over 4

=item C<init ()>

Sets the global variable C<$main::format>.

=item C<check ($file)>

Returns a SHA1 digest for the given file.  Needs to have read access for
the file to be checksummed.

=back

This module sets the following global variables

=over 4

=item <$main::format>

This is a regex that is used in a C<grep> routine to get the digest from
the filename, defaults to I<SHA1\\((.*)\\) = (.*)>

=back

=head1 CONFIGURATION OPTIONS

None.

=head1 HISTORY

This module was created from the sha script that I created many years ago.
When the install.pl script came about, I decided to simplify the code base
and only have one copy of the routine. 

=head1 TODO

Abstract this API out better to support changing of digest routines.

=head1 SEE ALSO

L<Digest::SHA1>

L<perl>

=cut
